/*-------------------------------------------------------------------------* 
 * GNU Prolog                                                              * 
 *                                                                         * 
 * Part  : Prolog buit-in predicates                                       * 
 * File  : all_pl_bips.pl                                                  * 
 * Descr.: all bips (to force the linker)                                  * 
 * Author: Daniel Diaz                                                     * 
 *                                                                         * 
 * Copyright (C) 1999-2002 Daniel Diaz                                     * 
 *                                                                         * 
 * GNU Prolog is free software; you can redistribute it and/or modify it   * 
 * under the terms of the GNU General Public License as published by the   * 
 * Free Software Foundation; either version 2, or any later version.       * 
 *                                                                         * 
 * GNU Prolog is distributed in the hope that it will be useful, but       * 
 * WITHOUT ANY WARRANTY; without even the implied warranty of              * 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU        * 
 * General Public License for more details.                                * 
 *                                                                         * 
 * You should have received a copy of the GNU General Public License along * 
 * with this program; if not, write to the Free Software Foundation, Inc.  * 
 * 59 Temple Place - Suite 330, Boston, MA 02111, USA.                     * 
 *-------------------------------------------------------------------------*/

/* $Id: all_pl_bips.pl,v 1.7 2002/04/09 08:26:39 diaz Exp $ */

'$use_all_pl_bips' :-
	'$use_control',
	'$use_call',
	'$use_call_args',
	'$use_catch',
	'$use_throw',
	'$use_unify',
	'$use_arith_inl',
	'$use_assert',
	'$use_all_solut',
	'$use_sort',
	'$use_list',
	'$use_stream',
	'$use_le_interf',
	'$use_file',
	'$use_char_io',
	'$use_read',
	'$use_write',
	'$use_print',
	'$use_const_io',
	'$use_oper',
	'$use_pred',
	'$use_atom',
	'$use_flag',
	'$use_term_inl',
	'$use_type_inl',
	'$use_g_var_inl',
	'$use_stat',
	'$use_dec10io',
	'$use_format',
	'$use_os_interf',
	'$use_expand',
	'$use_pretty',
	'$use_random',
	'$use_sockets',
 	'$use_src_rdr'.

